/*
    Copyright (C) 2008    Dmitry Ivanov <vonami@gmail.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef KRSSREADER_FEEDLISTMODEL_H
#define KRSSREADER_FEEDLISTMODEL_H

#include "treenode.h"

#include <akonadi/collection.h>
#include <akonadi/collectionmodel.h>
#include <akonadi/collectionfilterproxymodel.h>

class FeedlistModel : public QAbstractItemModel
{
        Q_OBJECT

public:

        enum Roles {
                TierRole = Akonadi::CollectionModel::UserRole + 1,
                XmlUrlRole,
                HtmlUrlRole,
                DescriptionRole,
                TagsRole,
                SubscriptionLabelsRole
        };

        enum Tier {
                TagTier,
                FeedTier
        };

public:

        explicit FeedlistModel( QObject *parent = 0 );
        ~FeedlistModel();

        void setSourceModel( Akonadi::CollectionModel *model );
        Akonadi::CollectionModel* sourceModel() const;

        Akonadi::Collection rootCollection() const;
        Akonadi::Collection collectionForId( const Akonadi::Collection::Id &colid ) const;
        QStringList allTags() const;
        QList<Akonadi::Collection::Id> allCollections() const;

        QString xmlUrl( const QModelIndex &index ) const;
        QString htmlUrl( const QModelIndex &index ) const;
        QString description( const QModelIndex &index ) const;
        QStringList tags( const QModelIndex &index ) const;
        QStringList subscriptionLabels( const QModelIndex &index ) const;

        QVariant headerData( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const;
        int columnCount( const QModelIndex &parent = QModelIndex() ) const;
        int rowCount( const QModelIndex &parent = QModelIndex() ) const;
        QVariant data( const QModelIndex &index, int role = Qt::DisplayRole ) const;
        QModelIndex index( int row, int column, const QModelIndex &parent = QModelIndex() ) const;
        QModelIndex parent( const QModelIndex &index ) const;


private Q_SLOTS:

        void slotDataChanged( const QModelIndex &start, const QModelIndex &end );
        void slotRowsInserted( const QModelIndex &parent, int start, int end );
        void slotRowsRemoved( const QModelIndex &parent, int start, int end );

protected:

        // helper methods
        QList<QModelIndex> feedIndexes( const Akonadi::Collection::Id &col ) const;

private:

        // helper methods
        QStringList lookupTags( const Akonadi::Collection::Id &id ) const;
        TreeNode* lookupFeedNode( const Akonadi::Collection::Id &id, const QString &tag ) const;
        void addFeedNode( const QModelIndex &sourceIndex );
        void dump() const;

private:

        Akonadi::CollectionFilterProxyModel *m_sourceModel;
        QString m_allFeedsTag;

        // it is hard to foresee the requirements to
        // the data structures until the model is finished
        // so i first finish the model and then try to come up with
        // the most convinient way to represent these mappings
        TreeNode *m_rootNode;
        QList<Akonadi::Collection::Id> m_collections;
        QHash<Akonadi::Collection::Id, QList<TreeNode*> > m_feedNodes;
        QHash<QString, TreeNode*> m_tagNodes;
};

#endif // KRSSREADER_FEEDLISTMODEL_H
