/*
    Copyright (C) 2008    Dmitry Ivanov <vonami@gmail.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "mainwidget.h"
#include "standardactionmanager.h"

#include <KXmlGuiWindow>

#include <QHBoxLayout>

MainWidget::MainWidget( KXmlGuiWindow *parent )
{
        QHBoxLayout *mainLayout = new QHBoxLayout( this );
        setLayout( mainLayout );

        m_mainSplitter = new QSplitter( Qt::Horizontal, this );
        mainLayout->addWidget( m_mainSplitter );

        m_fullModel = new Akonadi::CollectionModel( this );
        m_feedlistModel = new FeedlistModel( this );
        m_feedlistModel->setSourceModel( m_fullModel );
        m_filteredFeedlistModel = new FeedlistFilterProxyModel( this );
        m_filteredFeedlistModel->setSourceModel( m_feedlistModel );
        m_filteredFeedlistModel->setSubscriptionLabel( "krssreader" );
        m_feedlistView = new Akonadi::CollectionView( this );
        m_feedlistView->setModel( m_feedlistModel );

        m_articleSplitter = new QSplitter( Qt::Vertical, this );

        m_articlesModel = new Akonadi::ItemModel( this );
        m_articlesView = new Akonadi::ItemView( this );
        m_articlesView->setModel( m_articlesModel );
        m_articleViewer = new QTextEdit( this );
        m_articleSplitter->addWidget( m_articlesView );
        m_articleSplitter->addWidget( m_articleViewer );

        m_mainSplitter->addWidget( m_feedlistView );
        m_mainSplitter->addWidget( m_articleSplitter );

        StandardActionManager *actionManager = new StandardActionManager( parent->actionCollection(), this );
        actionManager->setFeedSelectionModel( m_feedlistView->selectionModel() );
        actionManager->setSubscriptionLabel( "krssreader" );
        actionManager->createAllActions();

        connect( m_feedlistView, SIGNAL( clicked( const Akonadi::Collection&) ),
                 m_articlesModel, SLOT( setCollection( const Akonadi::Collection& ) ) );
}

MainWidget::~MainWidget()
{
}

#include "mainwidget.moc"
