/*
    Copyright (C) 2008    Dmitry Ivanov <vonami@gmail.com>
    Part of the code borrowed from kdepimlibs/akonadi/standardactionmanager.h

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef KRSSREADER_STANDARDACTIONMANAGER_H
#define KRSSREADER_STANDARDACTIONMANAGER_H

#include <QObject>
#include <QVector>

class KAction;
class KActionCollection;
class QItemSelectionModel;
class QWidget;
class KJob;

class StandardActionManager : public QObject
{
        Q_OBJECT

public:

        enum Type {
                CreateFeed,
                SynchronizeFeed,
                FeedProperties,
                DeleteFeed,
                AttachNewTag,
                DetachTag,
                ManageSubscriptions,
                LastType
        };

        explicit StandardActionManager( KActionCollection *actionCollection, QWidget *parent = 0 );
        ~StandardActionManager();

        void setFeedSelectionModel( QItemSelectionModel *selectionModel );
        void setSubscriptionLabel( const QString &subscriptionLabel );
        KAction* action( Type type );
        void createAllActions();

private:

        //helper methods
        void enableAction( StandardActionManager::Type type, bool enable );

private Q_SLOTS:

        void slotCreateFeed();
        void slotSynchronizeFeed();
        void slotFeedProperties();
        void slotDeleteFeed();
        void slotAttachNewTag();
        void slotDetachTag();
        void slotManageSubscriptions();
        void updateActions();

        void collectionCreationResult( KJob* job );
        void collectionDeletionResult( KJob* job );
        void collectionModifyResult( KJob* job );

private:

        KActionCollection *m_actionCollection;
        QWidget *m_parentWidget;
        QItemSelectionModel *m_feedSelectionModel;
        QString m_subscriptionLabel;
        QVector<KAction*> m_actions;
};

#endif /* KRSSREADER_STANDARDACTIONMANAGER_H */
