/*
    Copyright (C) 2008    Dmitry Ivanov <vonami@gmail.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "subscriptionsmodel.h"

#include <akonadi/collectionmodel.h>
#include <KDebug>

#include <QStringList>

SubscriptionsModel::SubscriptionsModel( const QString &subscriptionLabel, QObject *parent )
        : FeedlistModel( parent ), m_subscriptionLabel( subscriptionLabel )
{
        connect( this, SIGNAL( rowsInserted( const QModelIndex&, int, int ) ),
                 this, SLOT( feedsInserted( const QModelIndex &, int, int ) ) );
}

SubscriptionsModel::~SubscriptionsModel()
{
}

void SubscriptionsModel::feedsInserted( const QModelIndex &parent, int start, int end )
{
        for ( int i = start; i <= end; ++i ) {
                QModelIndex sourceIndex = index( i, 0, parent );
                if ( FeedlistModel::data( sourceIndex, FeedlistModel::TierRole ) == FeedlistModel::FeedTier &&
                     subscriptionLabels( sourceIndex ).contains( m_subscriptionLabel ) ) {
                        Akonadi::Collection::Id id = FeedlistModel::data( sourceIndex, Akonadi::CollectionModel::CollectionIdRole ).
                                                                          value<Akonadi::Collection::Id>();
                        m_newSubscriptions.insert( id );
                        m_oldSubscriptions.insert( id );
                }
        }
}

QVariant SubscriptionsModel::data( const QModelIndex &index, int role ) const
{
        if ( !index.isValid() )
                return QVariant();

        if ( role == Qt::CheckStateRole && FeedlistModel::data( index, FeedlistModel::TierRole ) == FeedlistModel::FeedTier ) {
                const Akonadi::Collection::Id col = index.data( Akonadi::CollectionModel::CollectionIdRole ).toLongLong();
                return ( m_newSubscriptions.contains( col ) ? Qt::Checked : Qt::Unchecked );
        }

        return FeedlistModel::data( index, role );
}

bool SubscriptionsModel::setData( const QModelIndex &index, const QVariant &value, int role )
{
        if ( !index.isValid() )
                return false;

        if ( role == Qt::CheckStateRole && data( index, FeedlistModel::TierRole ) == FeedlistModel::FeedTier ) {
                const Akonadi::Collection::Id col = index.data( Akonadi::CollectionModel::CollectionIdRole ).toLongLong();

                if ( m_newSubscriptions.contains( col ) && value == Qt::Unchecked ) {
                        m_newSubscriptions.remove( col );
                        QList<QModelIndex> indexes = feedIndexes( col );
                        Q_FOREACH ( const QModelIndex &feed, indexes ) {
                                emit dataChanged( feed, feed );
                        }
                        kDebug() << "Subscriptions:" << m_newSubscriptions;
                        return true;
                }

                if ( !m_newSubscriptions.contains( col ) && value == Qt::Checked ) {
                        m_newSubscriptions << col;
                        QList<QModelIndex> indexes = feedIndexes( col );
                        Q_FOREACH ( const QModelIndex &feed, indexes ) {
                                emit dataChanged( feed, feed );
                        }
                        kDebug() << "Subscriptions:" << m_newSubscriptions;
                        return true;
                }

                return false;
        }

        return FeedlistModel::setData( index, value, role );
}

Qt::ItemFlags SubscriptionsModel::flags( const QModelIndex &index ) const
{
        Qt::ItemFlags flags = FeedlistModel::flags( index );
        if ( FeedlistModel::data( index, FeedlistModel::TierRole ) == FeedlistModel::FeedTier )
                flags = flags | Qt::ItemIsUserCheckable;

        return flags;
}

QSet<Akonadi::Collection::Id> SubscriptionsModel::newSubscriptions() const
{
        return m_newSubscriptions;
}

QSet<Akonadi::Collection::Id> SubscriptionsModel::oldSubscriptions() const
{
        return m_oldSubscriptions;
}

#include "subscriptionsmodel.moc"
