/*
    Copyright (C) 2008    Dmitry Ivanov <vonami@gmail.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "treenode.h"

#include <KDebug>

TreeNode::TreeNode( TreeNode::Tier tier, const Akonadi::Collection::Id &id, TreeNode *parent )
        : m_tier(tier), m_data(id), m_parent(parent)
{
}

TreeNode::TreeNode( TreeNode::Tier tier, const QString &name, TreeNode *parent )
        : m_tier(tier), m_data(name), m_parent(parent)
{
}

TreeNode::~TreeNode()
{
        removeChildren();
}

void TreeNode::appendChild( TreeNode *child )
{
        m_children << child;
}

void TreeNode::removeChildAt( int row )
{
        TreeNode *child = childAt( row );
        delete child;
        m_children.removeAt( row );
}

void TreeNode::removeChildren()
{
        qDeleteAll( m_children );
        m_children.clear();
}

int TreeNode::count() const
{
        return m_children.count();
}

TreeNode* TreeNode::childAt( int row ) const
{
        return m_children.value( row );
}

int TreeNode::childRow( TreeNode *child ) const
{
        return m_children.indexOf( child );
}

QList<TreeNode*> TreeNode::children() const
{
        return m_children;
}

TreeNode* TreeNode::parent() const
{
        return m_parent;
}

Akonadi::Collection::Id TreeNode::collection() const
{
        return m_data.value<Akonadi::Collection::Id>();
}

QString TreeNode::name() const
{
        return m_data.value<QString>();
}

TreeNode::Tier TreeNode::tier() const
{
        return m_tier;
}

int TreeNode::row() const
{
        // Since 'this' is of 'const TreeNode *const' type I can't just pass it
        // to QList::indexOf() which accepts 'TreeNode *'
        // Shame on me but I can't figure out a correct way to pass the pointer
        // to this object other than casting away constness.
        // Though this should be safe.
        return ( m_parent ? m_parent->childRow( const_cast<TreeNode*>( this ) ) : 0 );
}

void TreeNode::dump( QString indent ) const
{
        switch( m_tier ) {
                case RootNode:
                        kDebug() << QString( "%1%2" ).arg( indent ).arg( this->name() );
                        break;

                case TagNode:
                        kDebug() << QString( "%1%2" ).arg( indent ).arg( this->name() );
                        break;

                case FeedNode:
                        kDebug() << QString( "%1Feed, colid %2" ).arg( indent ).arg( this->collection() );
                        break;
        }

        Q_FOREACH( const TreeNode *child, m_children )
                child->dump( indent + "    " );
}
