/*
    Copyright (C) 2008    Dmitry Ivanov <vonami@gmail.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef KRSSREADER_TREENODE_H
#define KRSSREADER_TREENODE_H

#include <akonadi/collection.h>

#include <QVariant>

class TreeNode
{

public:

        enum Tier {
                RootNode,
                TagNode,
                FeedNode
        };

public:

        TreeNode( TreeNode::Tier tier, const Akonadi::Collection::Id &id, TreeNode *parent );
        TreeNode( TreeNode::Tier tier, const QString &name, TreeNode *parent );
        ~TreeNode();

        void appendChild( TreeNode *child );
        void removeChildAt( int row );
        void removeChildren();
        int count() const;
        TreeNode* childAt( int row ) const;
        int childRow( TreeNode *child ) const;
        QList<TreeNode*> children() const;
        TreeNode* parent() const;
        Akonadi::Collection::Id collection() const;
        QString name() const;
        TreeNode::Tier tier() const;
        int row() const;
        void dump( QString indent = QString() ) const;

private:

        TreeNode::Tier m_tier;
        QVariant m_data;
        TreeNode *m_parent;
        QList<TreeNode*> m_children;
};

#endif /* KRSSREADER_TREENODE_H */
