/*
    Copyright (C) 2008    Dmitry Ivanov <vonami@gmail.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "feedpropertiescollectionattribute.h"

FeedPropertiesCollectionAttribute::FeedPropertiesCollectionAttribute( )
        : Akonadi::Attribute()
{
}

QByteArray FeedPropertiesCollectionAttribute::type() const
{
        return "FeedProperties";
}

FeedPropertiesCollectionAttribute* FeedPropertiesCollectionAttribute::clone() const
{
        FeedPropertiesCollectionAttribute *attr = new FeedPropertiesCollectionAttribute();
        attr->setName( m_name );
        attr->setXmlUrl( m_xmlUrl );
        attr->setHtmlUrl( m_htmlUrl );
        attr->setFeedType( m_feedType );
        attr->setDescription( m_description );
        return attr;
}

QByteArray FeedPropertiesCollectionAttribute::serialized() const
{
        QStringList props;
        props << "Name=" + m_name;
        props << "XmlUrl=" + m_xmlUrl;
        props << "HtmlUrl=" + m_htmlUrl;
        props << "FeedType=" + m_feedType;
        props << "Description=" + m_description;
        return props.join( ";" ).toUtf8();
}

void FeedPropertiesCollectionAttribute::deserialize( const QByteArray &data )
{
        if ( data.isEmpty() )
                return;

        // so ugly, am i missing something?
        QStringList props = QString::fromUtf8( data.constData(), data.size() ).split( ';' );
        m_name = props[0].split( '=' )[1];
        m_xmlUrl = props[1].split( '=' )[1];
        m_htmlUrl = props[2].split( '=' )[1];
        m_feedType = props[3].split( '=' )[1];
        m_description = props[4].split( '=' )[1];
}

QString FeedPropertiesCollectionAttribute::name() const
{
        return m_name;
}

void FeedPropertiesCollectionAttribute::setName( const QString &name )
{
        m_name = name;
}

QString FeedPropertiesCollectionAttribute::xmlUrl() const
{
        return m_xmlUrl;
}

void FeedPropertiesCollectionAttribute::setXmlUrl( const QString &xmlUrl )
{
        m_xmlUrl = xmlUrl;
}

QString FeedPropertiesCollectionAttribute::htmlUrl() const
{
        return m_htmlUrl;
}

void FeedPropertiesCollectionAttribute::setHtmlUrl( const QString &htmlUrl )
{
        m_htmlUrl = htmlUrl;
}

QString FeedPropertiesCollectionAttribute::feedType() const
{
        return m_feedType;
}

void FeedPropertiesCollectionAttribute::setFeedType( const QString &feedType )
{
        m_feedType = feedType;
}

QString FeedPropertiesCollectionAttribute::description() const
{
        return m_description;
}

void FeedPropertiesCollectionAttribute::setDescription( const QString &description )
{
        m_description = description;
}
