/*
    Copyright (C) 2008    Dmitry Ivanov <vonami@gmail.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "tagscollectionattribute.h"

TagsCollectionAttribute::TagsCollectionAttribute( const QStringList &tags )
        : Attribute(), m_tags( tags )
{
}

QByteArray TagsCollectionAttribute::type() const
{
        return "Tags";
}

TagsCollectionAttribute* TagsCollectionAttribute::clone() const
{
        TagsCollectionAttribute *attr = new TagsCollectionAttribute( m_tags );
        return attr;
}

QByteArray TagsCollectionAttribute::serialized() const
{
        return m_tags.join( ";" ).toUtf8();
}

void TagsCollectionAttribute::deserialize( const QByteArray &data )
{
        if ( data.isEmpty() )
                return;

        // so ugly, am i missing something?
        m_tags = QString::fromUtf8( data.constData(), data.size() ).split( ';' );
}

QStringList TagsCollectionAttribute::tags() const
{
        return m_tags;
}

void TagsCollectionAttribute::setTags( const QStringList &tags )
{
        m_tags = tags;
}

void TagsCollectionAttribute::addTag( const QString &tag )
{
        if ( !m_tags.contains( tag ) )
                m_tags << tag;
}

void TagsCollectionAttribute::removeTag( const QString &tag )
{
        // addTag ensure the list contains no duplicates
        m_tags.removeOne( tag );
}
