/*
    Copyright (C) 2008    Dmitry Ivanov <vonami@gmail.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


#include "akonadi_serializer_rss.h"

#include <kfeed/item.h>
#include <kfeed/itemserializer.h>
#include <akonadi/item.h>

#include <QtCore/qplugin.h>

using namespace Akonadi;

bool SerializerPluginRss::deserialize(Item& item, const QByteArray& label, QIODevice& data, int version)
{
        Q_UNUSED(version)

        if ( label != Item::FullPayload )
                return false;

        KFeed::Item article;
        KFeed::ItemSerializer *ser = new KFeed::XmlItemSerializerImpl();
        ser->deserialize(article, data.readAll());

        item.setPayload<KFeed::Item>(article);
        return true;
}

void SerializerPluginRss::serialize(const Item& item, const QByteArray& label, QIODevice& data, int &version)
{
        Q_UNUSED(version)

        if ( label != Item::FullPayload )
                return;

        if ( item.mimeType() != QString::fromLatin1("application/rss+xml") )
                return;

        KFeed::Item article;
        if ( item.hasPayload() )
                article = item.payload<KFeed::Item>();

        KFeed::ItemSerializer *ser = new KFeed::XmlItemSerializerImpl();
        QByteArray array;
        ser->serialize(article, array);
        data.write(array);
}

Q_EXPORT_PLUGIN2(akonadi_serializer_rss, SerializerPluginRss)

#include "akonadi_serializer_rss.moc"
