/*
    Copyright (C) 2008    Dmitry Ivanov <vonami@gmail.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef AKONADI_RSS_RESOURCE
#define AKONADI_RSS_RESOURCE

#include <kfeed/item.h>
#include <syndication/syndication.h>
#include <akonadi/resourcebase.h>

#include <QHash>
#include <QXmlStreamReader>

class RssResource : public Akonadi::ResourceBase, public Akonadi::AgentBase::Observer
{
        Q_OBJECT
        Q_CLASSINFO("D-Bus Interface","org.kde.krss")

public:

        RssResource(const QString &id);

public Q_SLOTS:

        void configure(WId windowId);

        // D-Bus interface
        Q_NOREPLY void triggerBug();

protected Q_SLOTS:

        void retrieveCollections();
        void retrieveItems(const Akonadi::Collection &col);
        bool retrieveItem(const Akonadi::Item &item, const QSet<QByteArray> &parts);

private Q_SLOTS:

        void feedPropertiesFetched( Syndication::Loader *loader, Syndication::FeedPtr feed, Syndication::ErrorCode status );
        void feedContentFetched( Syndication::Loader *loader, Syndication::FeedPtr feed, Syndication::ErrorCode status );

private:

        void fetchFeedContent( const QString &url );
        void fetchFeedProperties( const QString &url );
        KFeed::Item convertToKFeedItem(const Syndication::ItemPtr &syndItem);
        void dump();

        bool loadOpml( const QString &path );
        void readUnknownElement();
        void readOpml();
        void readBody();
        void readOutline( QStringList &tags );

private:

        int m_fetchTries;

        Akonadi::Collection m_rootCollection;
        QHash<QString, Akonadi::Collection> m_collections;
        QList<Akonadi::Collection> m_changedCollections;
        QList<Akonadi::Collection> m_removedCollections;
        QXmlStreamReader m_reader;

        QDBusMessage m_replyMessage;
};

#endif /* AKONADI_RSS_RESOURCE */
